# Authors list

## Core devs

- Guillaume Bethouart
- Rémi Huguet (@remihuguet)
- Roman Mkrtchian (@roman.mkrtchian)

## eshard team

- Mickaël Bernardini (@mikafouenski)
- Pierre Carru
- Benoit Feix
- Georges Gagnerot
- Nadia Mourier (@Nanou89)
- Tiana Razafindralambo (@razaina)
- Lionel Rivière
- Hugues Thiebeauld
- Benjamin Timon
- François Vaux
- Aurélien Vasselle
- Guillaume Vinet (@gvinet)
- Antoine Wurcker
